@@ -371,7 +371,7 @@ def gold_to_kafka(input_table_name, data_pack_name, dataset_name, topic_name, in
     if spark is None:
         spark = get_spark_session(app_name=dataset_name)
     if reset_checkpoint:
-        __delete_checkpoint_location(checkpoint_location=checkpoint_location)
+        __delete_checkpoint_location(bucket_name=GOLD_BUCKET, checkpoint_location=checkpoint_location)
 
     df = read_table(spark, db_name=input_db_name, table_name=input_table_name)
     df = apply_processing_function(df=df, func=processing_function, func_args=processing_function_args, func_kwargs=processing_function_kwargs)
